cmake: A cross-platform build system generator
==============================================

Description
-----------

The "cmake" executable is the CMake command-line interface. It may be
used to configure projects in scripts. Project configuration settings
may be specified on the command line with the -D option. The -i option
will cause cmake to interactively prompt for such settings.

CMake is a cross-platform build system generator. Projects specify their
build process with platform-independent CMake listfiles included in each
directory of a source tree with the name CMakeLists.txt. Users build a
project by using CMake to generate a build system for a native tool on
their platform.

License
-------

CMake is distributed under the OSI-approved BSD 3-clause License.


Upstream Contact
----------------

-  https://cmake.org/

-  cmake-developers@cmake.org
